##  Activating the Extension
Admins can activate the AI governance extension in the administration area. Follow these steps:
  1. In the administration area, go to the Optional Features and Early Access section.
  2. For the AI Governance and Adoption extension, choose Activate, then confirm your action.
